@@ -2,7 +2,7 @@ import argparse
 from searcHPV.alignment import *
 from searcHPV.genome_fusion import *
 from searcHPV.assemble import *
-from searcHPV.hpv_fusion import *
+from searcHPV.virus_fusion import *
 
 def main(): 
 
@@ -71,11 +71,11 @@ def main():
         assemble(args.fq1, args.fq2, args.outputDir,args.virRef,args.gz,args.window)
     elif args.hpvFusion:
         #check result from assemble
-        hpv_fusion(args.humRef,args.virRef,args.outputDir,args.n)
+        virus_fusion(args.humRef,args.virRef,args.outputDir,args.n)
     else:
         alignment(fq1 = args.fq1, fq2 = args.fq2, humRef = args.humRef, virRef = args.virRef, outputDir = args.outputDir, gz = args.gz)
         genomeFusion(args.clusterWindow,args.outputDir,args.virRef)
         assemble(args.fq1, args.fq2, args.outputDir,args.virRef,args.gz,args.window)
-        hpv_fusion(args.humRef,args.virRef,args.outputDir)
+        virus_fusion(args.humRef,args.virRef,args.outputDir,args.n)
   
     
\ No newline at end of file
