@@ -692,7 +692,7 @@ def write_to_file(filteredSelectedContig,siteConfidence,out_dir,n):
         os.system(f'rm {outputPath}/HPVfusionPointContig.txt')
 
     # extract contigSeq
-    contigSeq = extractContigSeq(filteredSelectedContig,out_dir,n)
+    contigSeq = extractContigSeq(filteredSelectedContig,out_dir)
             
     with open(outputPath + 'HPVfusionPointContig.txt','w') as output: 
         output.write('contigName\tgenomeInsertionChromosome\tgenomeInsertionPoint\thpvInsertionPoint\tSiteConfidence\tContigConfidence\n')
